==> alfred-ui-native-components-0.0.153.tgz: package/ui/widgets/details/thermostat/components/setThermostatPoint/index.tsx <==
import { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { AcIcon, Body2MediumText, Body2RegularText, Body2SemiBoldText, HeadingXLargeText, HeatIcon } from '../../../../../atoms';
import { DragThumb, SpinnerThumb } from '../../../../../atoms/thumbs';
import { ContinuousSlider } from '../../../../../molecules';
import { styles } from './styles';

interface Props {
  title?: string,
  subtitle?: string,
  defaultValue?: string;
  ambientTemperature?: string;
  step: number;
  minValue: number;
  maxValue: number;
  onChangeValue?: (value: number) => void;
  loading?: boolean;
  enabled?: boolean;
}

const temperatureBySetPoint = (step: number, temperature: string) => {
  return step === 1 ? parseInt(temperature) : parseFloat(temperature);
};

const roundBySetPoint = (step: number, value: number) => {
  const inv = 1.0 / step;
  return Math.round(value * inv) / inv;
};

export const SetThermostatPoint: FC<Props> = ({
  title,
  subtitle,
  defaultValue = '',
  ambientTemperature,
  step,
  minValue,
  maxValue,
  onChangeValue,
  loading = false,
  enabled = true,
}) => {
  const [setPointTemperature, setSetPointTemperature] = useState<number>(temperatureBySetPoint(step, defaultValue));
  const [ambientThermostatTemperature, setAmbientThermostatTemperature] = useState<number|undefined>(
    ambientTemperature ? parseFloat(ambientTemperature) : undefined,
  );

  useEffect(() => {
    setSetPointTemperature(temperatureBySetPoint(step, defaultValue));
  }, [defaultValue]);

  useEffect(() => {
    ambientTemperature && setAmbientThermostatTemperature(parseFloat(ambientTemperature));
  }, [ambientTemperature]);

  const handleOnFinishChange = (value: number) => {
    onChangeValue?.(roundBySetPoint(step, value));
  };

  return (
    <>
      <View style={styles.setPointTextInfoWrapper}>
        {enabled &&
          <>
            <Body2SemiBoldText color={styles.setPointTitle.color}>{subtitle}</Body2SemiBoldText>
            <HeadingXLargeText>{setPointTemperature}ºC</HeadingXLargeText>
            {!!ambientThermostatTemperature &&
              <Body2MediumText color={styles.setPointSubtitle.color}>
                {title} {ambientThermostatTemperature}ºC
              </Body2MediumText>
            }
          </>
        }
        {!enabled &&
          !!ambientThermostatTemperature && 
          <>
            <HeadingXLargeText>{ambientThermostatTemperature}ºC</HeadingXLargeText>
            <Body2MediumText color={styles.setPointSubtitle.color}>
              {title}
            </Body2MediumText>
          </>
        }        
      </View>
      {enabled &&
        <View style={styles.setPointSliderWrapper}>
          <View style={styles.setPointSliderMaxMinTemperatures}>
            <Body2RegularText color={styles.setPointSliderMaxMinTemperatures.color}>{minValue}</Body2RegularText>
            <Body2RegularText color={styles.setPointSliderMaxMinTemperatures.color}>{maxValue}</Body2RegularText>
          </View>
          <ContinuousSlider
            ThumbComponent={loading ? SpinnerThumb : DragThumb}
            IconLeft={AcIcon}
            IconRight={HeatIcon}
            minValue={minValue}
            maxValue={maxValue}
            onStateChange={(value) => setSetPointTemperature(roundBySetPoint(step, value))}
            onFinishChange={handleOnFinishChange}
            defaultValue={setPointTemperature}
            isDisabled={loading || !enabled}
          />
        </View>
      }
    </>
  );
};

==> alfred-ui-native-components-0.0.159.tgz: package/ui/widgets/details/thermostat/components/setThermostatPoint/index.tsx <==
import { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { AcIcon, Body2MediumText, Body2RegularText, Body2SemiBoldText, HeadingXLargeText, HeatIcon } from '../../../../../atoms';
import { DragThumb, SpinnerThumb } from '../../../../../atoms/thumbs';
import { ContinuousSlider } from '../../../../../molecules';
import { styles } from './styles';

interface Props {
  title?: string,
  subtitle?: string,
  defaultValue?: string;
  ambientTemperature?: string;
  step: number;
  minValue: number;
  maxValue: number;
  onChangeValue?: (value: number) => void;
  loading?: boolean;
  enabled?: boolean;
}

const temperatureBySetPoint = (step: number, temperature: string) => {
  return step === 1 ? parseInt(temperature) : parseFloat(temperature);
};

const roundBySetPoint = (step: number, value: number) => {
  const inv = 1.0 / step;
  return Math.round(value * inv) / inv;
};

export const SetThermostatPoint: FC<Props> = ({
  title,
  subtitle,
  defaultValue = '',
  ambientTemperature,
  step,
  minValue,
  maxValue,
  onChangeValue,
  loading = false,
  enabled = true,
}) => {
  const [setPointTemperature, setSetPointTemperature] = useState<number>(temperatureBySetPoint(step, defaultValue));
  const [ambientThermostatTemperature, setAmbientThermostatTemperature] = useState<number|undefined>(
    ambientTemperature ? parseFloat(ambientTemperature) : undefined,
  );

  useEffect(() => {
    setSetPointTemperature(temperatureBySetPoint(step, defaultValue));
  }, [defaultValue]);

  useEffect(() => {
    ambientTemperature && setAmbientThermostatTemperature(parseFloat(ambientTemperature));
  }, [ambientTemperature]);

  const handleOnFinishChange = (value: number) => {
    onChangeValue?.(roundBySetPoint(step, value));
  };

  return (
    <>
      <View style={styles().setPointTextInfoWrapper}>
        {enabled &&
          <>
            <Body2SemiBoldText color={styles().setPointTitle.color}>{subtitle}</Body2SemiBoldText>
            <HeadingXLargeText>{setPointTemperature}ºC</HeadingXLargeText>
            {!!ambientThermostatTemperature &&
              <Body2MediumText color={styles().setPointSubtitle.color}>
                {title} {ambientThermostatTemperature}ºC
              </Body2MediumText>
            }
          </>
        }
        {!enabled &&
          !!ambientThermostatTemperature && 
          <>
            <HeadingXLargeText>{ambientThermostatTemperature}ºC</HeadingXLargeText>
            <Body2MediumText color={styles().setPointSubtitle.color}>
              {title}
            </Body2MediumText>
          </>
        }        
      </View>
      {enabled &&
        <View style={styles().setPointSliderWrapper}>
          <View style={styles().setPointSliderMaxMinTemperatures}>
            <Body2RegularText color={styles().setPointSliderMaxMinTemperatures.color}>{minValue}</Body2RegularText>
            <Body2RegularText color={styles().setPointSliderMaxMinTemperatures.color}>{maxValue}</Body2RegularText>
          </View>
          <ContinuousSlider
            ThumbComponent={loading ? SpinnerThumb : DragThumb}
            IconLeft={AcIcon}
            IconRight={HeatIcon}
            minValue={minValue}
            maxValue={maxValue}
            onStateChange={(value) => setSetPointTemperature(roundBySetPoint(step, value))}
            onFinishChange={handleOnFinishChange}
            defaultValue={setPointTemperature}
            isDisabled={loading || !enabled}
          />
        </View>
      }
    </>
  );
};
